@@ -37,6 +37,11 @@ class Freebox(IPlugin):
 		else:
 			bodies = "pas de lieu"
 
+		if jsonInput['outcome']['entities']['on_off']['value'] :
+			on_off = jsonInput['outcome']['entities']['on_off']['value']
+		else:
+			bodies = "pas de on/off"
+#
 		idex= location + "_" + on_off
 		log.msg("index :  %s" % (idex))	
 		
